@@ -61,7 +61,12 @@ static gboolean get_are_some_grabbed(GromitData *data)
 
 static void remove_hotkeys_from_compositor(GromitData *data) {
     char *xdg_current_desktop = getenv("XDG_CURRENT_DESKTOP");
-    if (xdg_current_desktop && strcmp(xdg_current_desktop, "GNOME") == 0) {
+
+    /* don't do anything when no keys are set at all */
+    if (!data->hot_keycode && !data->undo_keycode)
+	return;
+
+    if (xdg_current_desktop && strstr(xdg_current_desktop, "GNOME") != 0) {
 	/*
 	  Get all custom key bindings and save back the ones that are not from us.
 	*/
@@ -102,7 +107,12 @@ static void remove_hotkeys_from_compositor(GromitData *data) {
 
 static void add_hotkeys_to_compositor(GromitData *data) {
     char *xdg_current_desktop = getenv("XDG_CURRENT_DESKTOP");
-    if (xdg_current_desktop && strcmp(xdg_current_desktop, "GNOME") == 0) {
+
+    /* don't do anything when no keys are set at all */
+    if (!data->hot_keycode && !data->undo_keycode)
+	return;
+
+    if (xdg_current_desktop && strstr(xdg_current_desktop, "GNOME") != 0) {
 
 	if(data->debug)
 	    g_print("DEBUG: Detected GNOME under Wayland, adding our hotkeys to compositor\n");
@@ -232,15 +242,6 @@ void setup_input_devices (GromitData *data)
           devdata->index = i;
 
 	  /* get attached keyboard and grab the hotkey */
-	  if (!data->hot_keycode && !data->undo_keycode)
-	    {
-	      g_printerr("ERROR: Grabbing keys from attached keyboard of '%s' failed, hotkey or undo key not defined.\n",
-			 gdk_device_get_name(device));
-	      g_free(devdata);
-	      continue;
-	    }
-
-
 	  if (GDK_IS_X11_DISPLAY(data->display)) {
 	      gint dev_id = gdk_x11_device_get_id(device);
 
@@ -257,9 +258,6 @@ void setup_input_devices (GromitData *data)
  
 	      if(kbd_dev_id != -1)
 		  {
-		      if(data->debug)
-			  g_printerr("DEBUG: Grabbing hotkeys '%s' and '%s' from keyboard '%d' .\n", data->hot_keyval, data->undo_keyval, kbd_dev_id);
-
 		      XIEventMask mask;
 		      unsigned char bits[4] = {0,0,0,0};
 		      mask.mask = bits;
@@ -274,6 +272,9 @@ void setup_input_devices (GromitData *data)
 		      gdk_x11_display_error_trap_push(data->display);
 	      
 		      if (data->hot_keycode) {
+			  if(data->debug)
+			      g_printerr("DEBUG: Grabbing hot key '%s' from keyboard '%d' .\n", data->hot_keyval, kbd_dev_id);
+
 			  if(XIGrabKeycode(GDK_DISPLAY_XDISPLAY(data->display),
 					   kbd_dev_id,
 					   data->hot_keycode,
@@ -299,6 +300,9 @@ void setup_input_devices (GromitData *data)
 		      }
 
 		      if (data->undo_keycode) {
+			  if(data->debug)
+			      g_printerr("DEBUG: Grabbing undo key '%s' from keyboard '%d' .\n", data->undo_keyval, kbd_dev_id);
+
 			  if(XIGrabKeycode(GDK_DISPLAY_XDISPLAY(data->display),
 					   kbd_dev_id,
 					   data->undo_keycode,
